quantizationtools.QTargetMeasure
================================

.. abjad-lineage:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure

.. autoclass:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.beats
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.duration_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.offset_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.storage_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.tempo
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.time_signature
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.use_full_measure
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetMeasure.QTargetMeasure.QTargetMeasure.__repr__
   :noindex:
